==> hibernate-core-4.2.21.Final-sources.jar: org/hibernate/metamodel/relational/UniqueKey.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2010 by Red Hat Inc and/or its affiliates or by
 * third-party contributors as indicated by either @author tags or express
 * copyright attribution statements applied by the authors.  All
 * third-party contributions are distributed under license by Red Hat Inc.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.metamodel.relational;

import org.hibernate.dialect.Dialect;
import org.hibernate.internal.util.StringHelper;

/**
 * Models a SQL <tt>INDEX</tt> defined as UNIQUE
 *
 * @author Gavin King
 * @author Steve Ebersole
 */
public class UniqueKey extends AbstractConstraint implements Constraint {
	protected UniqueKey(Table table, String name) {
		super( table, name );
	}

	@Override
	public String getExportIdentifier() {
		StringBuilder sb = new StringBuilder( getTable().getLoggableValueQualifier() );
		sb.append( ".UK" );
		for ( Column column : getColumns() ) {
			sb.append( '_' ).append( column.getColumnName().getName() );
		}
		return sb.toString();
	}

	@Override
	public String[] sqlCreateStrings(Dialect dialect) {
		String s = dialect.getUniqueDelegate().applyUniquesOnAlter(this);
		return StringHelper.toArrayElement( s );
	}

	@Override
	public String[] sqlDropStrings(Dialect dialect) {
		String s = dialect.getUniqueDelegate().dropUniquesOnAlter(this);
		return StringHelper.toArrayElement( s );
	}

	@Override
    protected String sqlConstraintStringInAlterTable(Dialect dialect) {
		// not used
		return "";
	}
}

==> hibernate-core-4.3.5.Final-sources.jar: org/hibernate/metamodel/relational/UniqueKey.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2010 by Red Hat Inc and/or its affiliates or by
 * third-party contributors as indicated by either @author tags or express
 * copyright attribution statements applied by the authors.  All
 * third-party contributions are distributed under license by Red Hat Inc.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.metamodel.relational;

import org.hibernate.dialect.Dialect;
import org.hibernate.internal.util.StringHelper;

/**
 * Models a SQL <tt>INDEX</tt> defined as UNIQUE
 *
 * @author Gavin King
 * @author Steve Ebersole
 */
public class UniqueKey extends AbstractConstraint implements Constraint {
	protected UniqueKey(Table table, String name) {
		super( table, name );
	}

	@Override
	public String getExportIdentifier() {
		StringBuilder sb = new StringBuilder( getTable().getLoggableValueQualifier() );
		sb.append( ".UK" );
		for ( Column column : getColumns() ) {
			sb.append( '_' ).append( column.getColumnName().getName() );
		}
		return sb.toString();
	}

	@Override
	public String[] sqlCreateStrings(Dialect dialect) {
		String s = dialect.getUniqueDelegate().getAlterTableToAddUniqueKeyCommand( this );
		return StringHelper.toArrayElement( s );
	}

	@Override
	public String[] sqlDropStrings(Dialect dialect) {
		String s = dialect.getUniqueDelegate().getAlterTableToDropUniqueKeyCommand( this );
		return StringHelper.toArrayElement( s );
	}

	@Override
    protected String sqlConstraintStringInAlterTable(Dialect dialect) {
		// not used
		return "";
	}
}
